@@ -23,6 +23,9 @@
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
 #' @param annotations a character vector.
+#' @param by.group logical flag If TRUE repeated identical annotation layers are
+#'   added for each group within a plot panel as needed for animation. If
+#'   \code{FALSE}, the default, single layers are added per panel.
 #' @param geom character The name of a ggplot geometry, currently only
 #'   \code{"area"}, \code{"spct"} and \code{"line"}. The default \code{NULL}
 #'   selects between them based on \code{stacked}.
@@ -50,6 +53,7 @@ e_rsp_plot <- function(spct,
                        span,
                        wls.target,
                        annotations,
+                       by.group,
                        geom,
                        text.size,
                        idfactor,
@@ -81,7 +85,7 @@ e_rsp_plot <- function(spct,
       warning("Percent scale supported only for normalized cps_spct objects.")
       pc.out <- FALSE
     }
-    s.rsp.label <- expression(Spectral~~energy~~response~~k %*% R[E~lambda]~~("rel."))
+    s.rsp.label <- bquote(Spectral~~energy~~response~~k %*% R[E~lambda]~~("rel."))
     rsp.label.total <- "atop(k %*% R[E], (\"rel.\"))"
     rsp.label.avg <- "atop(bar(k %*% R[E~lambda]), (\"rel.\"))"
   } else if (photobiology::is_normalized(spct)) {
@@ -107,30 +111,30 @@ e_rsp_plot <- function(spct,
     }
     time.unit.char <- duration2character(time.unit)
     if (time.unit.char == "second") {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[E], (resp.~~unit~~s^{-1}))"
       rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~s^{-1}~nm^{-1}))"
     } else if (time.unit.char == "day") {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[E], (resp.~~unit~~d^{-1}))"
       rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~d^{-1}~nm^{-1}))"
     } else if (time.unit.char == "hour") {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[E], (resp.~~unit~~h^{-1}))"
       rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~h^{-1}~nm^{-1}))"
     } else if (time.unit.char == "duration") {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
       rsp.label.total  <- "atop(R[E], (resp.~~unit))"
       rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~nm^{-1}))"
       exposure.label <- paste("Length of time:",
                               ifelse(lubridate::is.duration(time.unit),
                                      as.character(time.unit), "unknown"))
     } else if (time.unit.char == "exposure") {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
       rsp.label.total  <- "atop(R[E], (resp.~~unit))"
       rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~nm^{-1}))"
     } else {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(arbitrary~~units))
+      s.rsp.label <- bquote(Spectral~~energy~~response~~R[E~lambda]~~(arbitrary~~units))
       rsp.label.total <- "atop(R[E], (arbitrary~~units))"
       rsp.label.avg <- "atop(bar(R[E~lambda]), (arbitrary~~units))"
     }
@@ -175,6 +179,7 @@ e_rsp_plot <- function(spct,
   temp <- find_idfactor(spct = spct,
                         idfactor = idfactor,
                         facets = facets,
+                        map.linetype = !facets && !by.group,
                         annotations = annotations)
   plot <- plot + temp$ggplot_comp
   annotations <- temp$annotations
@@ -190,7 +195,7 @@ e_rsp_plot <- function(spct,
     plot <- plot + geom_spct(fill = "black", colour = NA, alpha = 0.2)
   }
   plot <- plot + ggplot2::geom_line(na.rm = na.rm)
-  plot <- plot + labs(x = expression("Wavelength, "*lambda~(nm)), y = s.rsp.label)
+  plot <- plot + labs(x = bquote("Wavelength, "*lambda~(nm)), y = s.rsp.label)
 
   if (length(annotations) == 1 && annotations == "") {
     return(plot)
@@ -205,6 +210,7 @@ e_rsp_plot <- function(spct,
                             x.max = photobiology::wl_max(spct),
                             x.min = photobiology::wl_min(spct),
                             annotations = annotations,
+                            by.group = by.group,
                             label.qty = label.qty,
                             span = span,
                             wls.target = wls.target,
@@ -298,6 +304,7 @@ q_rsp_plot <- function(spct,
                        span,
                        wls.target,
                        annotations,
+                       by.group,
                        geom,
                        text.size,
                        idfactor,
@@ -330,7 +337,7 @@ q_rsp_plot <- function(spct,
       warning("Percent scale supported only for normalized response_spct objects.")
       pc.out <- FALSE
     }
-    s.rsp.label <- expression(Spectral~~photon~~response~~k %*% R[Q~lambda]~~("rel."))
+    s.rsp.label <- bquote(Spectral~~photon~~response~~k %*% R[Q~lambda]~~("rel."))
     rsp.label.total <- "atop(k %*% R[Q], (\"rel.\"))"
     rsp.label.avg <- "atop(bar(k %*% R[Q~lambda]), (\"rel.\"))"
   } else if (photobiology::is_normalized(spct)) {
@@ -356,30 +363,30 @@ q_rsp_plot <- function(spct,
     }
     time.unit.char <- duration2character(time.unit)
     if (time.unit.char == "second") {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[Q], (resp.~~unit~~s^{-1}))"
       rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~s^{-1}~nm^{-1}))"
     } else if (time.unit.char == "day") {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[Q], (resp.~~unit~~d^{-1}))"
       rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~d^{-1}~nm^{-1}))"
     } else if (time.unit.char == "hour") {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
       rsp.label.total  <- "atop(R[Q], (resp.~~unit~~h^{-1}))"
       rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~h^{-1}~nm^{-1}))"
     } else if (time.unit.char == "duration") {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
       rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
       rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~nm^{-1}))"
       exposure.label <- paste("Length of time:",
                               ifelse(lubridate::is.duration(time.unit),
                                      as.character(time.unit), "unknown"))
     } else if (time.unit.char == "exposure") {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
       rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
       rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~nm^{-1}))"
     } else {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(arbitrary~~units))
+      s.rsp.label <- bquote(Spectral~~photon~~response~~R[Q~lambda]~~(arbitrary~~units))
       rsp.label.total <- "atop(R[Q], (arbitrary~~units))"
       rsp.label.avg <- "atop(bar(R[Q~lambda]), (arbitrary~~units))"
     }
@@ -424,6 +431,7 @@ q_rsp_plot <- function(spct,
   temp <- find_idfactor(spct = spct,
                         idfactor = idfactor,
                         facets = facets,
+                        map.linetype = !facets && !by.group,
                         annotations = annotations)
   plot <- plot + temp$ggplot_comp
   annotations <- temp$annotations
@@ -439,7 +447,7 @@ q_rsp_plot <- function(spct,
     plot <- plot + geom_spct(fill = "black", colour = NA, alpha = 0.2)
   }
   plot <- plot + ggplot2::geom_line(na.rm = na.rm)
-  plot <- plot + ggplot2::labs(x = expression("Wavelength, "*lambda~(nm)),
+  plot <- plot + ggplot2::labs(x = bquote("Wavelength, "*lambda~(nm)),
                                y = s.rsp.label)
 
   if (length(annotations) == 1 && annotations == "") {
@@ -455,6 +463,7 @@ q_rsp_plot <- function(spct,
                             x.max = photobiology::wl_max(spct),
                             x.min = photobiology::wl_min(spct),
                             annotations = annotations,
+                            by.group = by.group,
                             label.qty = label.qty,
                             span = span,
                             wls.target = wls.target,
@@ -561,6 +570,7 @@ autoplot.response_spct <-
            span = NULL,
            wls.target = "HM",
            annotations = NULL,
+           by.group = FALSE,
            geom = "line",
            time.format = "",
            tz = "UTC",
@@ -588,6 +598,7 @@ autoplot.response_spct <-
                  span = span,
                  wls.target = wls.target,
                  annotations = annotations,
+                 by.group = by.group,
                  geom = geom,
                  time.format = time.format,
                  tz = tz,
@@ -653,6 +664,7 @@ autoplot.response_spct <-
                                span = span,
                                wls.target = wls.target,
                                annotations = annotations,
+                               by.group = by.group,
                                geom = geom,
                                text.size = text.size,
                                idfactor = idfactor,
@@ -668,6 +680,7 @@ autoplot.response_spct <-
                                span = span,
                                wls.target = wls.target,
                                annotations = annotations,
+                               by.group = by.group,
                                geom = geom,
                                text.size = text.size,
                                idfactor = idfactor,
@@ -696,6 +709,7 @@ autoplot.response_mspct <-
            norm = NA,
            unit.out = getOption("photobiology.radiation.unit", default="energy"),
            pc.out = getOption("ggspectra.pc.out", default = FALSE),
+           by.group = FALSE,
            plot.data = "as.is",
            facets = FALSE,
            idfactor = TRUE,
@@ -738,6 +752,7 @@ autoplot.response_mspct <-
                pc.out = pc.out,
                facets = facets,
                idfactor = NULL, # use idfactor already set in z
+               by.group = by.group,
                object.label = object.label,
                na.rm = na.rm,
                ...)
@@ -749,6 +764,7 @@ autoplot.response_mspct <-
                pc.out = pc.out,
                facets = facets,
                idfactor = NULL, # use idfactor already set in z
+               by.group = by.group,
                object.label = object.label,
                na.rm = na.rm,
                ...)
