@@ -24,20 +24,35 @@
 #'   \code{\link[ggplot2]{layer}} for more details.
 #' @param na.rm	a logical value indicating whether NA values should be
 #'   stripped before the computation proceeds.
-#' @param ignore_threshold numeric For peaks, value between 0.0 and 1.0
-#'   indicating the relative size of peaks compared to tallest peak threshold
-#'   below which peaks will be ignored, while negative values between 0.0 and
-#'   -1.0 set a threshold so that the tallest peaks are ignored, instead of the
-#'   shortest. For valleys, value between 0.0 and 1.0 indicating the relative
-#'   depth of valleys below which valleys will be ignored, while negative values
-#'   between 0.0 and -1.0 set a threshold so that the deeper valleys are
-#'   ignored, instead of the shallower ones.
-#' @param span integer A peak is defined as an element in a sequence which is
-#'   greater than all other elements within a window of width \code{span}
-#'   centered at that element. Use \code{NULL} for the global peak. Valleys are
-#'   the reverse.
-#' @param strict logical If \code{TRUE}, an element must be strictly greater
-#'   than all other values in its window to be considered a peak.
+#' @param global.threshold numeric A value belonging to class
+#'   \code{"AsIs"} is interpreted as an absolute minimum height or depth
+#'   expressed in data units. A bare \code{numeric} value (normally between 0.0
+#'   and 1.0), is interpreted as relative to the range of the data. In both
+#'   cases it sets a \emph{global} height (depth) threshold below which peaks
+#'   (valleys) are ignored. A bare negative \code{numeric} value indicates the
+#'   \emph{global} height (depth) threshold below which peaks (valleys) are be
+#'   ignored. If \code{global.threshold = NULL}, no threshold is applied and all
+#'   peaks are returned.
+#' @param ignore_threshold Deprecated synonym for \code{global.threshold}.
+#' @param local.threshold numeric A value belonging to class \code{"AsIs"} is
+#'   interpreted as an absolute minimum height (depth) expressed in data units
+#'   relative to the within-window computed minimum (maximum) value. A bare
+#'   \code{numeric} value (normally between 0.0 and 1.0), is interpreted as
+#'   expressed in units relative to the range of the data. In both cases
+#'   \code{local.threshold} sets a \emph{local} height (depth) threshold below
+#'   which peaks (valleys) are ignored. If \code{local.threshold = NULL} or if
+#'   \code{span} spans the whole of \code{x}, no threshold is applied.
+#' @param local.reference character One of \code{"minimum"}/\code{maximum} or
+#'   \code{"median"}. The reference used to assess the height of the peak,
+#'   either the minimum value within the window or the median of all values in
+#'   the window.
+#' @param span odd positive integer A peak is defined as an element in a
+#'   sequence which is greater than all other elements within a moving window of
+#'   width \code{span} centred at that element. The default value is 5, meaning
+#'   that a peak is taller than its four nearest neighbours. \code{span = NULL}
+#'   extends the span to the whole length of \code{x}.
+#' @param strict logical flag: if \code{TRUE}, an element must be strictly
+#'   greater than all other values in its window to be considered a peak.
 #' @param refine.wl logical Flag indicating if peak or valleys locations should
 #'   be refined by fitting a function.
 #' @param method character String with the name of a method used for peak
@@ -52,9 +67,12 @@
 #'   computing matching colours.
 #'
 #' @return A data frame with one row for each peak (or valley) found in the
-#'   data.
+#'   data. If \code{refine.wl = FALSE}, the returned rows have \code{x} and
+#'   \code{y} matching those in a row in the input \code{data}. If
+#'   \code{refine.wl = TRUE}, interpolation based on a fitted spline is used to
+#'   compute new \code{x} and \code{y} values.
 #'
-#' @section Computed variables:
+#' @section Computed and copied variables in the returned data frame:
 #' \describe{
 #'   \item{x}{x-value at the peak (or valley) as numeric}
 #'   \item{y}{y-value at the peak (or valley) as numeric}
@@ -91,6 +109,21 @@
 #'   \code{geom_hline} and \code{geom_vline}. The formatting of the labels
 #'   returned can be controlled by the user.
 #'
+#'   Two tests make it possible to ignore irrelevant peaks or valleys. One test
+#'   controlled by (\code{global.threshold}) is based on the absolute
+#'   height/depth  of peaks/valleys and can be used in all cases to ignore
+#'   globally low peaks and shallow valleys. A second test controlled by
+#'   (\code{local.threshold}) is available when the window defined by `span`
+#'   does not include all observations and can be used to ignore peaks/valleys
+#'   that are not locally prominent. In this second approach the height/depth of
+#'   each peak/valley is compared to a summary computed from other values within
+#'   the window where it was found. In this second case, the reference value
+#'   used is the summary indicated by \code{local.reference}. The values
+#'   \code{global.threshold} and \code{local.threshold} if bare numeric are
+#'   relative to the range of \emph{y}. Thresholds for ignoring too small peaks
+#'   are applied after peaks are searched for, and threshold values can in some
+#'   cases result in no peaks being displayed.
+#'
 #' @note These stats work nicely together with geoms
 #'   \code{geom_text_repel} and
 #'   \code{geom_label_repel} from package
@@ -103,22 +136,72 @@
 #'  be also easily obtained.
 #'
 #' @examples
-#'
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
+#'
+#' # PEAKS
+#'
 #' ggplot(sun.spct) +
 #'   geom_line() +
 #'   stat_peaks()
 #'
+#' # threshold relative to data range [0..1]
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_peaks(global.threshold = 0.6) # 0.6 * range of data
+#'
+#' # threshold in data units
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_peaks(global.threshold = I(0.4))
+#'
+#' # threshold in data units
+#' ggplot(sun.spct, unit.out = "photon") +
+#'   geom_line() +
+#'   stat_peaks(global.threshold = I(2e-6)) # Q in mol m-2 s-1
+#'
+#' # VALLEYS
+#'
 #' ggplot(sun.spct) +
 #'   geom_line() +
 #'   stat_valleys()
 #'
+#' # discard multiple maxima or minima
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_valleys(strict = TRUE)
+#'
+#' # threshold relative to data range [0..1]
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_valleys(global.threshold = 0.6)
+#'
+#' # reverse threshold relative to data range [-1..0]
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_valleys(global.threshold = -0.9)
+#'
+#' # threshold in data units using I()
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_valleys(global.threshold = I(0.6), strict = TRUE)
+#'
+#' # USING OTHER COMPUTED VALUES
+#'
+#' # colours matching the wavelength at peaks
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_peaks(span = 51, size = 2.7,
+#'              mapping = aes(colour = after_stat(wl.colour))) +
+#'   scale_color_identity()
+#'
+#' # labels for local maxima
 #' ggplot(sun.spct) +
 #'   geom_line() +
 #'   stat_peaks(span = 51, geom = "point", colour = "red") +
 #'   stat_peaks(span = 51, geom = "text", colour = "red",
 #'              vjust = -0.4, label.fmt = "%3.2f nm")
 #'
+#' # labels for local fitted peaks
 #' ggplot(sun.spct) +
 #'   geom_line() +
 #'   stat_peaks(span = 51, geom = "point", colour = "red", refine.wl = TRUE) +
@@ -126,17 +209,18 @@
 #'              vjust = -0.4, label.fmt = "%3.2f nm",
 #'              refine.wl = TRUE)
 #'
+#' # fitted peaks and valleys
 #' ggplot(sun.spct) +
 #'   geom_line() +
-#'   stat_peaks(span = 51, geom = "point", colour = "red", refine.wl = TRUE) +
+#'   stat_peaks(span = 31, geom = "point", colour = "red", refine.wl = TRUE) +
 #'   stat_peaks(mapping = aes(fill = after_stat(wl.colour), color = after_stat(BW.colour)),
-#'              span = 51, geom = "label",
-#'              size = 3, vjust = -0.2, label.fmt = "%.3g nm",
+#'              span = 31, geom = "label",
+#'              size = 3, vjust = -0.2, label.fmt = "%.4g nm",
 #'              refine.wl = TRUE) +
-#'   stat_valleys(span = 71, geom = "point", colour = "blue", refine.wl = TRUE) +
+#'   stat_valleys(span = 51, geom = "point", colour = "blue", refine.wl = TRUE) +
 #'   stat_valleys(mapping = aes(fill = after_stat(wl.colour), color = after_stat(BW.colour)),
-#'                span = 71, geom = "label",
-#'                size = 3, vjust = 1.2, label.fmt = "%.3g nm",
+#'                span = 51, geom = "label",
+#'                size = 3, vjust = 1.2, label.fmt = "%.4g nm",
 #'                refine.wl = TRUE) +
 #'   expand_limits(y = 0.85) + # make room for label
 #'   scale_fill_identity() +
@@ -152,15 +236,18 @@ stat_peaks <- function(mapping = NULL,
                        ...,
                        span = 5,
                        ignore_threshold = 0.01,
-                       strict = is.null(span),
+                       global.threshold = ignore_threshold,
+                       local.threshold = NULL,
+                       local.reference = "median",
+                       strict = FALSE,
                        refine.wl = FALSE,
                        method = "spline",
                        chroma.type = "CMF",
                        label.fmt = "%.3g",
                        x.label.fmt = label.fmt,
                        y.label.fmt = label.fmt,
-                       x.label.transform = I,
-                       y.label.transform = I,
+                       x.label.transform = function(x) {x},
+                       y.label.transform = function(x) {x},
                        x.colour.transform = x.label.transform,
                        na.rm = FALSE,
                        show.legend = FALSE,
@@ -168,14 +255,16 @@ stat_peaks <- function(mapping = NULL,
   if (!(is.function(x.label.transform) &&
         is.function(y.label.transform) &&
         is.function(x.colour.transform))) {
-    stop("'transform' arguments must be function defintions")
+    stop("'transform' arguments must be function definitions")
   }
 
   ggplot2::layer(
     stat = StatPeaks, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
     params = list(span = span,
-                  ignore_threshold = ignore_threshold,
+                  global.threshold = global.threshold,
+                  local.threshold = local.threshold,
+                  local.reference = local.reference,
                   strict = strict,
                   refine.wl = refine.wl,
                   method = method,
@@ -214,7 +303,9 @@ StatPeaks <-
                    compute_group = function(data,
                                             scales,
                                             span,
-                                            ignore_threshold,
+                                            global.threshold,
+                                            local.threshold,
+                                            local.reference,
                                             strict,
                                             refine.wl,
                                             method,
@@ -225,12 +316,16 @@ StatPeaks <-
                                             x.label.transform,
                                             y.label.transform,
                                             x.colour.transform) {
+
                      peaks.df <-
                        photobiology::peaks(data,
                                            x.var.name = "x",
                                            y.var.name = "y",
                                            span = span,
-                                           ignore_threshold = ignore_threshold,
+                                           global.threshold = global.threshold,
+                                           local.threshold = local.threshold,
+                                           local.reference = local.reference,
+                                           threshold.range = NULL,
                                            strict = strict,
                                            refine.wl = refine.wl,
                                            method = method,
@@ -263,16 +358,19 @@ stat_valleys <- function(mapping = NULL,
                          position = "identity",
                          ...,
                          span = 5,
-                         ignore_threshold = -0.01,
-                         strict = is.null(span),
+                         ignore_threshold = 0.01,
+                         global.threshold = ignore_threshold,
+                         local.threshold = NULL,
+                         local.reference = "median",
+                         strict = FALSE,
                          refine.wl = FALSE,
                          method = "spline",
                          chroma.type = "CMF",
                          label.fmt = "%.3g",
                          x.label.fmt = label.fmt,
                          y.label.fmt = label.fmt,
-                         x.label.transform = I,
-                         y.label.transform = I,
+                         x.label.transform = function(x) {x},
+                         y.label.transform = function(x) {x},
                          x.colour.transform = x.label.transform,
                          na.rm = FALSE,
                          show.legend = FALSE,
@@ -280,14 +378,16 @@ stat_valleys <- function(mapping = NULL,
   if (!(is.function(x.label.transform) &&
         is.function(y.label.transform) &&
         is.function(x.colour.transform))) {
-    stop("'transform' arguments must be function defintions")
+    stop("'transform' arguments must be function definitions")
   }
 
   ggplot2::layer(
     stat = StatValleys, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
     params = list(span = span,
-                  ignore_threshold = ignore_threshold,
+                  global.threshold = global.threshold,
+                  local.threshold = local.threshold,
+                  local.reference = local.reference,
                   strict = strict,
                   refine.wl = refine.wl,
                   method = method,
@@ -312,7 +412,9 @@ StatValleys <-
                    compute_group = function(data,
                                             scales,
                                             span,
-                                            ignore_threshold,
+                                            global.threshold,
+                                            local.threshold,
+                                            local.reference,
                                             strict,
                                             refine.wl,
                                             method,
@@ -323,12 +425,16 @@ StatValleys <-
                                             x.label.transform,
                                             y.label.transform,
                                             x.colour.transform) {
+
                      valleys.df <-
                        photobiology::valleys(data,
                                              x.var.name = "x",
                                              y.var.name = "y",
                                              span = span,
-                                             ignore_threshold = ignore_threshold,
+                                             global.threshold = global.threshold,
+                                             local.threshold = local.threshold,
+                                             local.reference = local.reference,
+                                             threshold.range = NULL,
                                              strict = strict,
                                              refine.wl = refine.wl,
                                              method = method,
